function y = reverb_schroeder(x, Tr, m_H, m_A, g_A);
% x: input signal; m_H: N-dim array of delays (in samples) of combs H_i; 
% m_A: M-dim array of delays (in samples) of all-passes A_i; 
% g_A: M-dim array of all-pass gains 

global Fs;
y = zeros(length(x),1); %output signal updated after each single filter
for i=1:length(m_H)          %parallel comb filtering
    g_H = 10^(-3*m_H(i)/(Fs*Tr));         % gain of ith comb
    num_H = [zeros(1,m_H(i)),1];          % numerator of ith comb
    den_H = [1,zeros(1,m_H(i)-1),-g_H];   % denominator of ith comb    
    y = y + filter(num_H, den_H, x);      % update comb parallel
end
for i=1:length(m_A)          %series all-pass filtering
    num_A = [-g_A(i),zeros(1,m_A(i)-1),1]; % numerator of ith all-pass
    den_A = [1,zeros(1,m_A(i)-1),-g_A(i)]; % denominator of ith all-pass
    y = filter(num_A,den_A,y);             % update all-pass series
end

