function [Tr,edc] = revtime(rir,Fs,ti,tf);
%Returns an estimate of Tr and of the edc; rir is a row vector representing
%a RIR, ti and tf are the initial and final times on which edc is computed

rir=rir(round(ti*Fs):round(tf*Fs));  % chunk the RIR on the interval [ti,tf]
edc =  10*log10(fliplr(cumsum(fliplr(rir.^2)))); % compute EDC
edc = edc-max(edc);                              %normalize at 0 dB

%linearly fit edc in the first half and find Tr as 
%the instant where the linear fit drops below -60dB
c = polyfit(1:round(length(edc)/2),edc(1:round(length(edc)/2)),1);
Tr = (-60-c(2))/(c(1)*Fs);   % edc=c2 +c1*Fs*t;   edc=-60 => this formula
